@@ -1,27 +1,26 @@
 # -*- coding: utf-8 -*-
 
-from curses import ascii
-
-from fontbro.flags import get_flag, set_flag
-from fontbro.subset import parse_unicodes
-from fontbro.utils import read_json, slugify
-
-from fontTools import unicodedata
-from fontTools.subset import Subsetter, Options as SubsetterOptions
-from fontTools.ttLib import TTFont, TTLibError
-from fontTools.varLib import instancer
-from fontTools.varLib.instancer import OverlapMode
-
-from PIL import Image, ImageDraw, ImageFont
-
 import copy
-import fsutil
 import itertools
 import math
 import os
 import re
 import sys
 import tempfile
+from curses import ascii
+
+import fsutil
+from fontTools import unicodedata
+from fontTools.subset import Options as SubsetterOptions
+from fontTools.subset import Subsetter
+from fontTools.ttLib import TTFont, TTLibError
+from fontTools.varLib import instancer
+from fontTools.varLib.instancer import OverlapMode
+from PIL import Image, ImageDraw, ImageFont
+
+from fontbro.flags import get_flag, set_flag
+from fontbro.subset import parse_unicodes
+from fontbro.utils import concat_names, read_json, slugify
 
 
 class Font(object):
@@ -413,6 +412,34 @@ class Font(object):
             format = self.FORMAT_WOFF2
         return format
 
+    def get_glyphs(self):
+        """
+        Gets the font glyphs and their own composition.
+
+        :returns: The glyphs.
+        :rtype: generator of dicts
+        """
+        font = self.get_ttfont()
+        glyf = font["glyf"]
+        glyphset = font.getGlyphSet()
+        for name in glyphset.keys():
+            yield {
+                "name": name,
+                "components_names": glyf[name].getComponentNames(glyf),
+            }
+
+    def get_glyphs_count(self):
+        """
+        Gets the font glyphs count.
+
+        :returns: The glyphs count.
+        :rtype: int
+        """
+        font = self.get_ttfont()
+        glyphset = font.getGlyphSet()
+        count = len(glyphset)
+        return count
+
     def get_image(
         self, text, size, color=(0, 0, 0, 255), background_color=(255, 255, 255, 255)
     ):
@@ -876,7 +903,6 @@ class Font(object):
             or self.get_name(self.NAME_WWS_SUBFAMILY_NAME)
             or self.get_name(self.NAME_SUBFAMILY_NAME)
         )
-        concat_names = lambda a, b: f"{a} {b}" if not a.endswith(f" {b}") else a
 
         # typographic and wws names
         typographic_family_name = family_name
@@ -913,7 +939,14 @@ class Font(object):
             typographic_family_name.replace(" ", ""),
             typographic_subfamily_name.replace(" ", ""),
         )
-        postscript_name = re.sub(r"[^a-zA-Z0-9\-]", "-", postscript_name)
+
+        # keep only printable ASCII subset: https://learn.microsoft.com/en-us/typography/opentype/spec/name#name-ids
+        # postscript_name_allowed_chars = {chr(code) for code in range(33, 127)} - {"[", "]", "(", ")", "{", "}", "<", ">", "/", "%"}
+        # !"#$&'*+,-.0123456789:;=?@ABCDEFGHIJKLMNOPQRSTUVWXYZ\^_`abcdefghijklmnopqrstuvwxyz|~
+        postscript_name_pattern = (
+            r"[^0-9A-Za-z\!\"\#\$\&\'\*\+\,\-\.\:\;\=\?\@\\\^\_\`\|\~]"
+        )
+        postscript_name = re.sub(postscript_name_pattern, "-", postscript_name)
         postscript_name = re.sub(r"[\-]+", "-", postscript_name).strip("-")
         postscript_name_length = len(postscript_name)
         if postscript_name_length > 63:
@@ -971,10 +1004,10 @@ class Font(object):
         extension = format
         filename = fsutil.join_filename(basename, extension)
         filepath = fsutil.join_filepath(dirpath, filename)
-        if filepath == self._filepath and not overwrite:
+        if fsutil.is_file(filepath) and not overwrite:
             raise ValueError(
-                "Invalid filepath, value cannot be the same of the initial filepath"
-                " to prevent accidental font files overwrites."
+                f"Invalid filepath, a file already exists at '{filepath}' "
+                "and 'overwrite' option is 'False' (consider using 'overwrite=True')."
             )
         fsutil.make_dirs_for_file(filepath)
 
